<%-- $Id: view_reporter.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Johan Enell, Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ExtendedProperties"
	import="net.sf.basedb.core.ExtendedProperty"
	import="net.sf.basedb.core.Type"
	import="net.sf.basedb.core.Reporter"
	import="net.sf.basedb.core.ReporterType"
	import="net.sf.basedb.core.data.ReporterData"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultIterator"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ButtonAction" 
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="p" uri="/WEB-INF/path.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.REPORTER;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.ITEM);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":View "+itemType);
try
{
	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);

	String title = null;
	ReporterData reporter = Reporter.getById(dc, itemId);
	
	final boolean writePermission = sc.hasPermission(Permission.WRITE, itemType);
	final boolean deletePermission = sc.hasPermission(Permission.DELETE, itemType);
	Formatter<Date> dateTimeFormatter = FormatterFactory.getDateTimeFormatter(sc);
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, reporter);
	ExtensionsInvoker<ButtonAction> invoker = ToolbarUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title%>" id="view-page">
	<base:head scripts="tabcontrol-2.js,~reporters.js" styles="toolbar.css,headertabcontrol.css,path.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<p:path><p:pathelement 
			title="Reporters" href="<%="index.jsp?ID="+ID%>" 
			/><p:pathelement title="<%=HTML.encodeTags(reporter.getName())%>" 
			/></p:path>
		<div id="page-data" data-item-id="<%=itemId%>"></div>
		
		<t:tabcontrol 
			id="main" 
			subclass="content mastertabcontrol" 
			active="properties">
		<t:tab id="properties" title="Properties">
			<div>
			<table class="fullform bottomborder">
			<tr>
				<th class="itemstatus"></th>
				<td style="padding: 0px;">
					<tbl:toolbar subclass="bottomborder bg-filled-50">
						<tbl:button 
							id="btnEdit"
							disabled="<%=!writePermission%>" 
							image="edit.png" 
							title="Edit&hellip;" 
							tooltip="<%=writePermission ? "Edit this reporter" : "You do not have permission to edit this reporter"%>" 
						/>
						<tbl:button 
							id="btnDelete"
							data-confirm="1"
							disabled="<%=!deletePermission%>" 
							image="delete.png" 
							title="Delete&hellip;" 
							tooltip="<%=deletePermission ? "Delete this reporter" : "You do not have permission to delete this reporter"%>" 
						/>
						<tbl:button 
							id="btnImport"
							image="import.png" 
							data-plugin-type="IMPORT"  
							title="Import&hellip;" 
							tooltip="Import data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.IMPORT)%>"
						/>
						<tbl:button 
							id="btnExport"
							image="export.png"
							data-plugin-type="EXPORT" 
							title="Export&hellip;" 
							tooltip="Export data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
						/>
						<tbl:button 
							id="btnRunPlugin"
							image="runplugin.png"  
							data-plugin-type="OTHER" 
							title="Run plugin&hellip;" 
							tooltip="Run a plugin" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
						/>
						<tbl:button
							image="help.png"
							subclass="auto-init"
							data-auto-init="help"
							data-help-id="reporter.view.properties"
							title="Help&hellip;"
							tooltip="Get help about this page"
						/>
						<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
							wrapper="<%=new PrefixSuffixRenderer<ButtonAction>(jspContext, "<td>", "</td>") %>"/>
					</tbl:toolbar>
				</td>
			</tr>
			<tr>
				<th>Name</th>
				<td><%=HTML.encodeTags(reporter.getName())%></td>
			</tr>
			<tr>
				<th>External ID</th>
				<td><%=HTML.encodeTags(reporter.getExternalId())%></td>
			</tr>
			<tr>
				<th>Type</th>
				<td><base:propertyvalue dbcontrol="<%=dc%>" item="<%=reporter%>" property="reporterType" /></td>
			</tr>
			<tr>
				<th>Registered</th>
				<td><%=dateFormatter.format(reporter.getEntryDate())%></td>
			</tr>
			<tr>
				<th>Last update</th>
				<td><%=dateTimeFormatter.format(reporter.getLastUpdate())%></td>
			</tr>
			<tr>
				<th class="subprompt">- from/by</th>
				<td><%=HTML.niceFormat(reporter.getLastSource())%></td>
			</tr>
			<tr>
				<th>Gene symbol</th>
				<td><%=HTML.encodeTags(reporter.getSymbol())%></td>
			</tr>
				<tr>
					<th>Permissions</th>
					<td>
					<%=sc.hasPermission(Permission.READ, itemType) ? "Read" : ""%>
					<%=sc.hasPermission(Permission.USE, itemType) ? ", Use" : ""%>
					<%=sc.hasPermission(Permission.WRITE, itemType) ? ", Write" : ""%>
					<%=sc.hasPermission(Permission.DELETE, itemType) ? ", Delete" : ""%>					
					</td>
				</tr>
			<tr>
				<th>Description</th>
				<td><%=HTML.niceFormat(reporter.getDescription())%></td>
			</tr>
			</table>
			</div>
			<%
			List<ExtendedProperty> reporterProperties = ExtendedProperties.getProperties("ReporterData");
			%>
			<base:section
				id="extendedProperties"
				title="<%="Extended properties (" + reporterProperties.size() + ")"%>"
				context="<%=cc%>"
				>
				<table class="fullform fullborder">
					<%				
					if (reporterProperties != null)
					{
						boolean needsTr = true;
						for (ExtendedProperty ep : reporterProperties)
						{
							String name = ep.getName();
							Formatter<Object> f = FormatterFactory.getExtendedPropertyFormatter(sc, ep);
							String value = f.format(reporter.getExtended(name));
							%>
								<%=needsTr ? "<tr><th>" : "<th class=\"leftborder\">" %>
								<%=HTML.encodeTags(ep.getTitle())%></th>
								<td><%=value%></td>
								<%=needsTr ? "" : "</tr>"%>
							<%
							needsTr = !needsTr;
						}
						%>
						<%=needsTr ? "" : "<th class=\"leftborder\"></th><td></td></tr>"%>
						<%
					}
					%>
				</table>
			</base:section>
		</t:tab>
		</t:tabcontrol>


	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}

%>
